@@ -5,5 +5,6 @@ Application init
 # Django
 from django.utils.translation import gettext_lazy as _
 
-__version__ = "2.3.1"
-__title__ = _("Time Zones")
+__version__ = "2.4.3"
+__title__ = "Time Zones"
+__title_translated__ = _("Time Zones")
