@@ -4,9 +4,10 @@ App config
 
 # Django
 from django.apps import AppConfig
+from django.utils.text import format_lazy
 
 # AA Time Zones
-from timezones import __version__
+from timezones import __title_translated__, __version__
 
 
 class AaTimezonesConfig(AppConfig):
@@ -16,4 +17,6 @@ class AaTimezonesConfig(AppConfig):
 
     name: str = "timezones"
     label: str = "timezones"
-    verbose_name: str = f"Timezones v{__version__}"
+    verbose_name = format_lazy(
+        "{app_title} v{version}", app_title=__title_translated__, version=__version__
+    )
